@@ -1,6 +1,7 @@
 package Locale::Maketext::Lexicon;
-$Locale::Maketext::Lexicon::VERSION = '0.60';
+$Locale::Maketext::Lexicon::VERSION = '0.61';
 
+use 5.004;
 use strict;
 
 =head1 NAME
@@ -9,8 +10,8 @@ Locale::Maketext::Lexicon - Use other catalog formats in Maketext
 
 =head1 VERSION
 
-This document describes version 0.60 of Locale::Maketext::Lexicon,
-released April 13, 2006.
+This document describes version 0.61 of Locale::Maketext::Lexicon,
+released April 27, 2006.
 
 =head1 SYNOPSIS
 
@@ -502,15 +503,27 @@ L<Locale::Maketext::Lexicon::Tie>
 
 =head1 AUTHORS
 
-Audrey Tang E<lt>audreyt@audreyt.orgE<gt>
+Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT (The "MIT" License)
 
-Copyright 2002-2006 by Audrey Tang E<lt>audreyt@audreyt.orgE<gt>.
+Copyright 2002-2006 by Audrey Tang <cpan@audreyt.org>.
 
-This program is free software; you can redistribute it and/or 
-modify it under the same terms as Perl itself.
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is fur-
+nished to do so, subject to the following conditions:
 
-See L<http://www.perl.com/perl/misc/Artistic.html>
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FIT-
+NESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE X
+CONSORTIUM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
+ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
+WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 =cut
